/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createDimension;

import org.fortiss.tooling.base.model.layout.Dimension;
import org.fortiss.tooling.base.model.layout.ILayoutData;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;

/**
 * Utility class for {@link Dimension} layout data.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 5BDF0EA81728D59FBC5E27E00904D085
 */
public final class DimensionUtils {

	/**
	 * Returns a {@link Dimension} layout data object with the given key.
	 * 
	 * @param layouted
	 *            the layouted model element
	 * @param key
	 *            the layout key
	 * @return the dimension of the element
	 */
	public static Dimension getDimension(ILayoutedModelElement layouted, String key) {
		for(ILayoutData ld : layouted.getLayoutDataList()) {
			if(ld.getKey().equals(key) && ld instanceof Dimension) {
				return (Dimension)ld;
			}
		}
		return null;
	}

	/**
	 * Sets a {@link Dimension} layout data object with the given key.
	 * 
	 * @param layouted
	 *            the layouted model element
	 * @param key
	 *            the layout key
	 * @param w
	 *            the width
	 * @param h
	 *            the height
	 */
	public static void setDimension(ILayoutedModelElement layouted, String key, int w, int h) {
		Dimension old = getDimension(layouted, key);
		if(old != null) {
			old.setWidth(w);
			old.setHeight(h);
		} else {
			layouted.getLayoutDataList().add(createDimension(w, h, key));
		}
	}
}
