/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createPoint;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.fortiss.tooling.base.model.layout.ILayoutData;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.model.layout.Point;

/**
 * Utility class for handling {@link Point} layout data, i.e., position of nodes
 * in a graphical layout.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 497062A726321ADDE1E6991D61DE481F
 */
public final class PointUtils {

	/**
	 * Gets the position stored at the given key.
	 * 
	 * @param layouted
	 *            the layouted model element
	 * @param key
	 *            the layout key
	 * @return the point stored under the layout key
	 */
	public static Point getPosition(ILayoutedModelElement layouted, String key) {
		Point point = getPoint(layouted, key);

		if(point == null) {
			int index = 0;
			EObject container = layouted.eContainer();
			if(container != null) {
				index = 1 + container.eContents().indexOf(layouted);
			}
			Point p = createPoint(index * 20, index * 20, key);
			return p;
		}
		return EcoreUtil.copy(point);
	}

	/** Returns a {@link Point} layout data object with the given key or null. */
	private static Point getPoint(ILayoutedModelElement layouted, String key) {
		for(ILayoutData ld : layouted.getLayoutDataList()) {
			if(ld.getKey().equals(key) && ld instanceof Point) {
				return (Point)ld;
			}
		}
		return null;
	}

	/**
	 * Sets a {@link Point} layout data.
	 * 
	 * @param layouted
	 *            the layouted model element
	 * @param key
	 *            the layout key
	 * @param x
	 *            the x coordinate value
	 * @param y
	 *            the y coordinate value
	 */
	public static void setPoint(ILayoutedModelElement layouted, String key, int x, int y) {
		Point old = getPoint(layouted, key);
		if(old != null) {
			old.setX(x);
			old.setY(y);
		} else {
			layouted.getLayoutDataList().add(createPoint(x, y, key));
		}
	}
}
